@@ -1,3 +1,4 @@
+
 #include <Alib.h>
 
 #define IsInside(w, pt)	pt.x < w->clip.x1 || pt.x >= w->clip.x2 || \
@@ -8,29 +9,24 @@
  */
 
 void
-Clip2DPolygon (w, pts, npts, clippedPts, nClippedPts)
-AWindow	*w;
-Point	*pts;
-int	npts;
-Point	*clippedPts;
-int	*nClippedPts;
+Clip2DPolygon(AWindow * w, Point * pts, int npts, Point * clippedPts, int *nClippedPts)
 {
 
-	register int	numPts, j, lastj, inside, lastInside;
-	int		x1, y1, x2, y2;
+	register int numPts, j, lastj, inside, lastInside;
+	int       x1, y1, x2, y2;
 
 	lastj = npts - 1;
 	numPts = 0;
 
-	lastInside = IsInside (w, pts[lastj]) ? 1 : 0;
+	lastInside = IsInside(w, pts[lastj]) ? 1 : 0;
 
-	for (j=0; j < npts; ++j) {
+	for (j = 0; j < npts; ++j) {
 
 		if (lastInside == 1) {
 			clippedPts[numPts++] = pts[lastj];
 		}
 
-		inside = (IsInside (w, pts[j])) ? 1 : 0;
+		inside = (IsInside(w, pts[j])) ? 1 : 0;
 
 /*
  *  Fast, but not accurate.  This method does not handle polygons in corners
@@ -42,7 +38,7 @@ int	*nClippedPts;
 			y1 = pts[lastj].y;
 			x2 = pts[j].x;
 			y2 = pts[j].y;
-			ClipLine (w, &x1, &y1, &x2, &y2);
+			ClipLine(w, &x1, &y1, &x2, &y2);
 			if (x2 == pts[lastj].x && y2 == pts[lastj].y) {
 				clippedPts[numPts].x = x1;
 				clippedPts[numPts++].y = y1;
@@ -59,4 +55,3 @@ int	*nClippedPts;
 
 	*nClippedPts = numPts;
 }
-
