@@ -1,3 +1,4 @@
+
 #include <Alib.h>
 
 /*
@@ -12,19 +13,22 @@
 #include <malloc.h>
 #else
 extern void free();
+
 #endif
 #endif
 
 void
-CloseAWindow (w)
-AWindow *w;
+CloseAWindow(AWindow * w)
 {
-	free ((char *) w->edges);
-	free ((char *) w->lines);
-	free ((char *) w->edgePool);
-	free ((char *) w->csPool0);
-	free ((char *) w->csPool1);
-	free ((char *) w->scanLine);
-	free ((char *) w->lastScanLine);
-	free ((char *) w);
+	free((char *) w->edges);
+	free((char *) w->lines);
+	free((char *) w->edgePool);
+	free((char *) w->csPool0);
+	free((char *) w->csPool1);
+	if (w->doubleBuffered) {
+		free((char *) w->csPool2);
+	}
+	free((char *) w->scanLine);
+	free((char *) w->lastScanLine);
+	free((char *) w);
 }
