@@ -1,14 +1,13 @@
+
 #include <Alib.h>
 
-extern int MakeET();
+extern int MakeET(AWindow * w, Point * pts, int npts, ZInfo * zinfo);
 
-void FillRectangle (w, x, y, width, height, zinfo)
-AWindow	*w;
-int	x, y;
-int	width, height;
-ZInfo	*zinfo; {
+void
+FillRectangle(AWindow * w, int x, int y, int width, int height, ZInfo * zinfo)
+{
 
-	Point	pts[4];
+	Point     pts[4];
 	register int yextent, xextent;
 
 /*
@@ -44,5 +43,5 @@ ZInfo	*zinfo; {
 	pts[3].x = x;
 	pts[3].y = yextent;
 
-	MakeET (w, pts, 4, zinfo);
+	MakeET(w, pts, 4, zinfo);
 }
