@@ -1,39 +1,48 @@
 #include <Alib.h>
 #include <stdio.h>
 
-extern void EdgeTableToScanLine (), ScanLineDifference();
+extern void EdgeTableToScanLine(AWindow * w), ScanLineDifference(AWindow * w);
 
-void FrameComplete (w)
-AWindow		*w; {
+void
+FrameComplete(AWindow * w)
+{
+
+	register ScanLine *tmp;
+	register int i;
 
-	register ScanLine	*tmp;
-	register int		i;
 #ifdef DEBUG
-	register int		cstop;
+	register int cstop;
+
 #endif
 
 /*
  *  Convert the edge table to scan line segments.
  */
 
-	EdgeTableToScanLine (w);
+	EdgeTableToScanLine(w);
 
 /*
  *  Determine the differences between this frame and the previous one
  *  an plot the differences.
  */
 
-	ScanLineDifference (w);
+	ScanLineDifference(w);
 
 /*
  *  This frame now becomes the previous frame; clear the new current frame.
  */
 
 	tmp = w->lastScanLine;
-	w->lastScanLine = w->scanLine;
+	if (w->doubleBuffered) {
+		w->lastScanLine = w->otherLastScanLine;
+		w->otherLastScanLine = w->scanLine;
+	}
+	else {
+		w->lastScanLine = w->scanLine;
+	}
 	w->scanLine = tmp;
 
-	for (i=0; i<(w->height+1); ++i) {
+	for (i = 0; i < (w->height + 1); ++i) {
 		w->scanLine[i].count = 0;
 		w->edges[i].head = (Edge *) NULL;
 		w->lines[i].head = (Edge *) NULL;
@@ -50,6 +59,22 @@ AWindow		*w; {
 #endif
 		w->CSTop1 = 0;
 	}
+	else if (w->curPool == 1) {
+		if (w->doubleBuffered) {
+			w->curPool = 2;
+#ifdef DEBUG
+			cstop = w->CSTop2;
+#endif
+			w->CSTop2 = 0;
+		}
+		else {
+			w->curPool = 0;
+#ifdef DEBUG
+			cstop = w->CSTop0;
+#endif
+			w->CSTop0 = 0;
+		}
+	}
 	else {
 		w->curPool = 0;
 #ifdef DEBUG
@@ -63,7 +88,7 @@ AWindow		*w; {
  */
 
 #ifdef DEBUG
-	printf ("color segments = %d; edges = %d\n", cstop, w->EPTop);
+	printf("color segments = %d; edges = %d\n", cstop, w->EPTop);
 #endif
 
 	w->EPTop = 0;
@@ -76,11 +101,11 @@ AWindow		*w; {
  */
 
 #ifdef X11
-	AX11FlushBufferedSegments (w);
+	AX11FlushBufferedSegments(w);
 #endif
 
 #ifdef DEBUG
-	printf ("End of Frame\n");
+	printf("End of Frame\n");
 #endif
 
 }
