@@ -1,13 +1,14 @@
+
 #include "Vlib.h"
 #include <math.h>
 
 void
-VComputeClipNormals (v)
-Viewport *v; {
+VComputeClipNormals(Viewport * v)
+{
 
-	VPoint	*p, *q;
-	int	i, max;
-	double  mag;
+	VPoint   *p, *q;
+	int       i, max;
+	double    mag;
 
 	p = v->clipPoly->vertex;
 	q = v->clipNormals;
@@ -22,8 +23,8 @@ Viewport *v; {
  *  Compute the unit-normal vectors corresponding to each clipping plane
  */
 
-	for (i=0; i<max; ++i) {
-		mag = sqrt (p->x * p->x + p->y * p->y + p->z * p->z);
+	for (i = 0; i < max; ++i) {
+		mag = sqrt(p->x * p->x + p->y * p->y + p->z * p->z);
 		q->x = p->x / mag;
 		q->y = p->y / mag;
 		q->z = p->z / mag;
