@@ -2,11 +2,10 @@
 #include <math.h>
 
 void
-VComputeObjectExtent(obj)
-VObject *obj;
+VComputeObjectExtent(VObject * obj)
 {
-	VPoint	sum;
-	register int	i, j, npts = 0;
+	VPoint    sum;
+	register int i, j, npts = 0;
 	register double d;
 
 	obj->extent = 0.0;
@@ -19,14 +18,14 @@ VObject *obj;
  *  determine the average location (i.e. the center).
  */
 
-	for (i=0; i<obj->numPolys; ++i) {
+	for (i = 0; i < obj->numPolys; ++i) {
 
-		for (j=0; j<obj->polygon[i]->numVtces; ++j) {
+		for (j = 0; j < obj->polygon[i]->numVtces; ++j) {
 
 			sum.x += obj->polygon[i]->vertex[j].x;
 			sum.y += obj->polygon[i]->vertex[j].y;
 			sum.z += obj->polygon[i]->vertex[j].z;
-			++ npts;
+			++npts;
 		}
 	}
 
@@ -40,16 +39,16 @@ VObject *obj;
  *   Determine the most distant point from the center of the object
  */
 
-		for (i=0; i<obj->numPolys; ++i) {
-			for (j=0; j<obj->polygon[i]->numVtces; ++j) {
+		for (i = 0; i < obj->numPolys; ++i) {
+			for (j = 0; j < obj->polygon[i]->numVtces; ++j) {
 				sum.x = obj->polygon[i]->vertex[j].x -
 					obj->center.x;
 				sum.y = obj->polygon[i]->vertex[j].y -
 					obj->center.y;
 				sum.z = obj->polygon[i]->vertex[j].z -
 					obj->center.z;
-				d = sqrt (sum.x * sum.x + sum.y * sum.y +
-					sum.z * sum.z);
+				d = sqrt(sum.x * sum.x + sum.y * sum.y +
+						 sum.z * sum.z);
 				if (d > obj->extent)
 					obj->extent = d;
 			}
