@@ -1,14 +1,10 @@
 #include "Vlib.h"
 
-void VDrawString(v, win, gc, p, str, len)
-Viewport *v;
-Window	 win;
-GC	 gc;
-VPoint	 *p;
-char	 *str;
-int	 len; {
+void
+VDrawString(Viewport * v, Window win, GC gc, VPoint * p, char *str, int len)
+{
 
-	register int	x, y;
+	register int x, y;
 
 	if (v->flags & VPPerspective) {
 		x = (v->Middl.x + (int) (v->Scale.x * p->x / p->z)) >> 2;
@@ -19,6 +15,6 @@ int	 len; {
 		y = (v->Middl.y - (int) (v->Scale.y * p->y)) >> 2;
 	}
 
-	XDrawString (v->dpy, win, gc, x, y, str, len);
+	XDrawString(v->dpy, win, gc, x, y, str, len);
 
 }
