@@ -1,3 +1,4 @@
+
 #include "Vlib.h"
 
 /*
@@ -8,10 +9,9 @@
  *  VWorldToEye can be used to convert world coordinates to x,y values.
  */
 
-int VEyeToScreen (v, p, x, y)
-Viewport	*v;
-VPoint		*p;
-int		*x, *y; {
+int
+VEyeToScreen(Viewport * v, VPoint * p, int *x, int *y)
+{
 
 	register int valid;
 
