@@ -1,21 +1,21 @@
 #include "Vlib.h"
 
-static VMatrix ident = {
+static VMatrix ident =
+{
 	1.0, 0.0, 0.0, 0.0,
 	0.0, 1.0, 0.0, 0.0,
 	0.0, 0.0, 1.0, 0.0,
 	0.0, 0.0, 0.0, 1.0
-	};
+};
 
 void
-VIdentMatrix (Mtx)
-VMatrix *Mtx;
+VIdentMatrix(VMatrix * Mtx)
 {
 #ifdef notdef
-	short I, J;
+	short     I, J;
 
-	for (I=0; I<4; ++I)
-		for (J=0; J<4; ++J)
+	for (I = 0; I < 4; ++I)
+		for (J = 0; J < 4; ++J)
 			if (I == J)
 				(*Mtx).m[I][J] = 1.0;
 			else
