@@ -6,13 +6,12 @@
  *  displayable (probably displayable, that is).
  */
 
-int VWorldToScreen (v, p, x, y)
-Viewport	*v;
-VPoint		*p;
-int		*x, *y; {
+int
+VWorldToScreen(Viewport * v, VPoint * p, int *x, int *y)
+{
 
-	VPoint	eyept;
+	VPoint    eyept;
 
-	VTransform (p, &(v->eyeSpace), &eyept);
-	return VEyeToScreen (v, &eyept, x, y);
+	VTransform(p, &(v->eyeSpace), &eyept);
+	return VEyeToScreen(v, &eyept, x, y);
 }
