@@ -1,3 +1,4 @@
+
 /*
  *  acm : an aerial combat simulator for X
  *  Copyright (C) 1991,1992  Riley Rainey
@@ -19,18 +20,18 @@
 #ifndef _alarm_h
 #define _alarm_h
 
-typedef long	alarm_id_t;
+typedef long alarm_id_t;
 
 typedef struct _alarm_descriptor_t {
 	struct _alarm_descriptor_t *next;
-	double	delta;
+	double    delta;
 	alarm_id_t alarm_id;
-	void	(*proc)();
-	char	*arg1;
-	char	*arg2;
-	}	alarm_descriptor_t;
+	void      (*proc) ();
+	char     *arg1;
+	char     *arg2;
+} alarm_descriptor_t;
 
-extern alarm_id_t addAlarm();
-extern double cancelAlarm();
+extern alarm_id_t addAlarm(double delta, void (*proc) (char *, char *), char *arg1, char *arg2);
+extern double cancelAlarm(alarm_id_t id);
 
 #endif
