@@ -16,26 +16,27 @@
  *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
  */
 typedef struct {
-	VPoint	Sg;
-	VPoint	Cg;
-	double	heading, pitch, roll;
-	}	_BBShortState;
+        WorldCoordinates w;
+	VPoint    Sg;
+	VPoint    Cg;
+	double    heading, pitch, roll;
+} _BBShortState;
 
 typedef struct {
-	short	type;			/* craft type */
-	char	name[64];		/* craft name */
-	}	_BBNewObject;
+	short     type;				/* craft type */
+	char      name[64];			/* craft name */
+} _BBNewObject;
 
 typedef struct {
-	unsigned	rectype:3;	/* black box record type */
-	unsigned	table:1;	/* is it ptbl(0) or mtbl(1)? */
-	unsigned	id:11;		/* player or missile index */
-	union	{
-	_BBShortState	short_state;
-	_BBNewObject	object;
-	}	u;
-	}	BBRecord;
-
+	unsigned  char rectype;		/* black box record type */
+	unsigned  char table;			/* is it ptbl(0) or mtbl(1)? */
+	unsigned  short id;			/* player or missile index */
+	union {
+		_BBShortState short_state;
+		_BBNewObject object;
+	} u;
+} BBRecord;
+#define BB_HDR_SIZE (sizeof(char) + sizeof(char) + sizeof(short))
 
 #define BB_TYPE_SHORT_STATE		0x00
 #define BB_TYPE_ADD_OBJECT		0x01
