@@ -1,6 +1,7 @@
+
 /*
  *  acm : an aerial combat simulator for X
- *  Copyright (C) 1991-1994  Riley Rainey
+ *  Copyright (C) 1991-1996  Riley Rainey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,11 +17,15 @@
  *  Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
  */
 
-
 /*
  *  PLATFORM-SPECIFIC VALUES
  */
 
+#ifdef WIN32
+#define printf acm_printf
+#define fprintf acm_fprintf
+#endif
+
 #if !defined(HAVE_COPYSIGN)
 #define NEEDS_COPYSIGN
 #endif
@@ -29,17 +34,9 @@
 #include <unistd.h>
 #endif
 
-#ifdef hpux
+#ifdef __hpux
 #define sigvec sigvector
-#else
-#if (defined SVR4) || (defined __linux__)
-#define sigvec                sigaction
-#define sv_handler    sa_handler
-#define sv_mask               sa_mask
-#define sv_flags      sa_flags
-#define SV_INTERRUPT  SA_RESTART
-#endif /* SVR4 */
-#endif /* hpux */
+#endif							/* hpux */
 
 #if defined(HAVE_STDLIB_H)
 #include <stdlib.h>
@@ -58,7 +55,7 @@
  */
 
 #ifndef MAXSURFACE
-#define MAXSURFACE	64
+#define MAXSURFACE	128
 #endif
 
 /*
@@ -66,16 +63,15 @@
  */
 
 #ifndef MAXPLAYERS
-#define MAXPLAYERS	16
+#define MAXPLAYERS	32
 #endif
 
-
 /*
  *  Maximum number of observers
  */
 
 #ifndef MAXOBSERVERS
-#define MAXOBSERVERS    16
+#define MAXOBSERVERS    1
 #endif
 
 /*
@@ -83,7 +79,7 @@
  */
 
 #ifndef MAXCHASERS
-#define MAXCHASERS      16
+#define MAXCHASERS      1
 #endif
 
 /*
@@ -99,7 +95,7 @@
 #endif
 
 #ifndef MAXCRAFTTYPES
-#define MAXCRAFTTYPES	64
+#define MAXCRAFTTYPES	128
 #endif
 
 #ifndef STATIONS
@@ -110,23 +106,6 @@
 #define WEAPONTYPES	4
 #endif
 
-/*
- *  Number of microseconds between each update (when not in "real time" mode)
- */
-
-#ifndef UPDATE_INTERVAL 
-#define UPDATE_INTERVAL		125000
-#endif
-
-/*
- *  REDRAW_EVERY defines the number of update intervals between each
- *  redraw of player screens.
- */
-
-#ifndef REDRAW_EVERY
-#define REDRAW_EVERY		1
-#endif
-
 /*
  *  We'll check every now and again to see if any aircraft are waiting to
  *  be resupplied.  RESUPPLY_EVERY defines the number of seconds
@@ -138,13 +117,25 @@
 #endif
 
 /*
- *  ACM_PORT define the internet port number to be used in the game 
- *  startup handshaking.
+ *  The default exercise id and site id to use for DIS.
+ *  These are overrriden on the acm command line with the "-dis-xxx"
+ *  options.
+ *  (Note that the default DIS application id of zero means that acm
+ *   will choose an application id from the host address that have
+ *   a high probability of beeing unique.)
  */
 
-#ifndef ACM_PORT
-#define ACM_PORT		3232
-#endif
+#define DIS_EXERCISE		1
+#define DIS_SITE		17
+#define DIS_APPLICATION		0
+
+/*
+ *  The maximum allowed dead reckoning errors for DIS.
+ *  (Note: the units are meters and radians.)
+ */
+
+#define DIS_LOCATION_THRESHOLD		3.0
+#define DIS_ORIENTATION_THRESHOLD	(2*3.141593/180.0)
 
 /*
  *  ACM becomes the name used to lookup X resources on a particular
@@ -162,6 +153,12 @@
 
 /* #define LINEAR_CONTROL_RESPONSE */
 
+/*
+ *  NO_FUZZ removes the "no response" area around center stick position.
+ */
+ 
+/* #define NO_FUZZ */
+     
 /*
  *  We have code in-place to perform flight debugging.  Define this to
  *  compile in that code.
@@ -186,6 +183,14 @@
 #define ACM_LIBRARY		"/usr/local/games/acm/"
 #endif
 
+/*
+ *  SRCDIR is the toplevel directory of the source tree
+ */
+
+#ifndef SRCDIR
+#define SRCDIR	".."
+#endif
+
 /*
  *  a signal handler function type
  */
@@ -194,18 +199,12 @@
 #define acm_sig_t       RETSIGTYPE
 #else
 #ifdef SIGVOID
-#define acm_sig_t	void	/* System V returns void */
+#define acm_sig_t	void		/* System V returns void */
 #else
-#define acm_sig_t	int	/* BSD does int's */
+#define acm_sig_t	int			/* BSD does int's */
 #endif
 #endif
 
-/*
- *  When debugging, undefine this to disable alarm signals.
- */
-
-/* #define USE_ALARM */
-
 /*
  *  I have defined some special purpose, debugging keys;  define
  *  SPECIAL_KEYS to enable their use.
@@ -232,7 +231,7 @@
  *  to remain idle before it should exit.
  */
 
-#define MAX_GAME_IDLE_SECONDS	120.0
+#define MAX_GAME_IDLE_SECONDS	0.0
 
 /*
  *  DEFAULT_DRONE_FACTOR controls how hard drones are allowed to maneuver.
@@ -246,3 +245,17 @@
  */
 
 #define MIN_DRONE_FACTOR 	0.05
+
+/*
+ *  MAG_VAR sets the magnetic heading offset from true heading.
+ */
+
+#define MAG_VAR			0.0
+
+/*
+ *  CLOUD_BASE and CLOUD_TOP sets the altitude of base and top of
+ *  the cloud layer in feet. If base == top, no clouds are used.
+ */
+
+#define CLOUD_BASE		0
+#define CLOUD_TOP		0
